// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function pathmat = file_split ( name  )
  // Split the path.
  // 
  // Calling Sequence
  // pathmat = file_split ( name )
  //
  // Parameters
  // name : a 1-by-1 matrix of strings
  // pathmat : a n-by-1 matrix of strings
  //
  // Description
  // Returns a matrix of string for each separator found in name.
  // 
  // Examples
  // name = file_tempfile (  )
  // pathmat = file_split ( name )
  //
  // pathmat = file_split ( "/foo/myfile.txt" )
  // 
  
  // We should use strsplit, but this does not work
  //pathmat = strsplit(name,["\" "/" ":"],256)
  sepmat(1) = filesep()
  sepmat(2) = file_canonicalsep ( )
  pathmat = []
  buff = ""
  for k = 1 : length(name)
    c = part(name,k:k)
    if ( or(c==sepmat) ) then
      pathmat($+1) = buff
      buff = ""
    else
      buff = buff + c
    end
  end
  if ( buff <> "" ) then
    pathmat($+1) = buff
  end
  pathmat(pathmat=="")=[]
endfunction
function sep = file_canonicalsep ( )
  // Returns the platform-dependent canonical separator.
  // 
  // Calling Sequence
  // sep = file_canonicalsep ( )
  //
  // Parameters
  // sep : a 1-by-1 matrix of strings, sep="/" on Windows and Linux, sep=":" on Mac
  //
  // Description
  // Returns the platform-dependent canonical separator.
  // 
  // Examples
  // sep = file_canonicalsep ( )
  // 
  
  os = getos()
  if ( os=="Windows" ) then
    sep = "/"
  elseif ( os=="Linux" ) then
    sep = "/"
  else
    sep = ":"
  end
endfunction



function test_runfromdemo ( demoscript , modulename )
  // Launch the unit tests of the module from the demonstrations.
  //
  // Parameters
  //   demoscript : the name of the demonstration script
  //   modulename : the name of the module
  // 
  // Description
  //   The unit tests of the module are launched from 
  //   a demonstration script located in the demonstrations directory.
  //   We use the test_run function appropriately, by changing 
  //   the current directory and passing the good input argument
  //   to it.
  //
  // Author
  //   2010 - DIGITEO - Michael Baudin
  
  demopath = get_absolute_file_path(demoscript);
  //
  parts = file_split(demopath)
  dirpath = parts($-1)
  cwd = pwd();
  mprintf("Running unit tests for module : %s\n",modulename );
  cd(demopath+"../..");
  mprintf("Current directory : %s\n",pwd());
  if ( fileinfo(dirpath)<>[] ) then
    test_run(dirpath);
  else
    if ( atomsIsLoaded(modulename) ) then
      atomsTest(modulename)
    else
      errmsg = msprintf(gettext("%s: The %s module is not loaded.") , "test_runfromdemo", modulename) 
      error ( errmsg )
    end
  end
  cd(cwd);
  
endfunction

test_runfromdemo ( "runtests.sce" , "fmincont" );

